@@ -1,11 +1,11 @@
 from collections import defaultdict
 from typing import Any
 
-from elementary.clients.dbt.dbt_runner import DbtRunner
+from elementary.clients.dbt.base_dbt_runner import BaseDbtRunner
 
 
 class FetcherClient:
-    def __init__(self, dbt_runner: DbtRunner):
+    def __init__(self, dbt_runner: BaseDbtRunner):
         self.dbt_runner = dbt_runner
         self.run_cache = defaultdict(lambda: None)
 
