@@ -30,6 +30,7 @@ class ModelAlert(Alert):
         self.materialization = materialization
         self.message = message
         self.full_refresh = full_refresh
+        self.alerts_table = ModelAlert.TABLE_NAME
 
     def to_slack(self, is_slack_workflow: bool = False) -> SlackMessageSchema:
         if is_slack_workflow:
@@ -203,3 +204,11 @@ class ModelAlert(Alert):
         return self.slack_message_builder.get_slack_message(
             title=title, preview=preview, result=result, configuration=configuration
         )
+
+    @property
+    def consice_name(self):
+        if self.materialization == "snapshot":
+            text = "snapshot"
+        else:
+            text = "model"
+        return f"dbt {text} alert - {self.alias}"
