@@ -1,9 +1,8 @@
-import json
 from collections import defaultdict
 from datetime import datetime
-from typing import Callable, Dict, List, Optional, Union
+from typing import Dict, List, Union
 
-from elementary.clients.api.api import APIClient
+from elementary.clients.api.api_client import APIClient
 from elementary.clients.dbt.dbt_runner import DbtRunner
 from elementary.config.config import Config
 from elementary.monitor.alerts.alerts import Alerts, AlertsQueryResult, AlertType
@@ -12,10 +11,9 @@ from elementary.monitor.alerts.model import ModelAlert
 from elementary.monitor.alerts.source_freshness import SourceFreshnessAlert
 from elementary.monitor.alerts.test import TestAlert
 from elementary.monitor.api.alerts.alert_filters import filter_alerts
-from elementary.monitor.api.alerts.normalized_alert import NormalizedAlert
-from elementary.monitor.data_monitoring.schema import DataMonitoringAlertsFilter
+from elementary.monitor.data_monitoring.schema import SelectorFilterSchema
+from elementary.monitor.fetchers.alerts.alerts import AlertsFetcher
 from elementary.utils.log import get_logger
-from elementary.utils.time import get_now_utc_str
 
 logger = get_logger(__name__)
 
@@ -30,12 +28,17 @@ class AlertsAPI(APIClient):
         super().__init__(dbt_runner)
         self.config = config
         self.elementary_database_and_schema = elementary_database_and_schema
+        self.alerts_fetcher = AlertsFetcher(
+            dbt_runner=self.dbt_runner,
+            config=self.config,
+            elementary_database_and_schema=self.elementary_database_and_schema,
+        )
 
     def get_new_alerts(
         self,
         days_back: int,
         disable_samples: bool = False,
-        filter: Optional[DataMonitoringAlertsFilter] = None,
+        filter: SelectorFilterSchema = SelectorFilterSchema(),
     ) -> Alerts:
         new_test_alerts = self.get_test_alerts(days_back, disable_samples, filter)
         new_model_alerts = self.get_model_alerts(days_back, filter)
@@ -52,12 +55,14 @@ class AlertsAPI(APIClient):
         self,
         days_back: int,
         disable_samples: bool = False,
-        filter: Optional[DataMonitoringAlertsFilter] = None,
+        filter: SelectorFilterSchema = SelectorFilterSchema(),
     ) -> AlertsQueryResult[TestAlert]:
-        pending_test_alerts = self._query_pending_test_alerts(
+        pending_test_alerts = self.alerts_fetcher.query_pending_test_alerts(
             days_back, disable_samples
         )
-        last_alert_sent_times = self._query_last_test_alert_times(days_back)
+        last_alert_sent_times = self.alerts_fetcher.query_last_test_alert_times(
+            days_back
+        )
         test_alerts = self._sort_alerts(
             pending_test_alerts, last_alert_sent_times, filter
         )
@@ -66,10 +71,12 @@ class AlertsAPI(APIClient):
     def get_model_alerts(
         self,
         days_back: int,
-        filter: Optional[DataMonitoringAlertsFilter] = None,
+        filter: SelectorFilterSchema = SelectorFilterSchema(),
     ) -> AlertsQueryResult[ModelAlert]:
-        pending_model_alerts = self._query_pending_model_alerts(days_back)
-        last_alert_sent_times = self._query_last_model_alert_times(days_back)
+        pending_model_alerts = self.alerts_fetcher.query_pending_model_alerts(days_back)
+        last_alert_sent_times = self.alerts_fetcher.query_last_model_alert_times(
+            days_back
+        )
         model_alerts = self._sort_alerts(
             pending_model_alerts, last_alert_sent_times, filter
         )
@@ -78,17 +85,31 @@ class AlertsAPI(APIClient):
     def get_source_freshness_alerts(
         self,
         days_back: int,
-        filter: Optional[DataMonitoringAlertsFilter] = None,
+        filter: SelectorFilterSchema = SelectorFilterSchema(),
     ) -> AlertsQueryResult[SourceFreshnessAlert]:
-        pending_source_freshness_alerts = self._query_pending_source_freshness_alerts(
-            days_back
+        pending_source_freshness_alerts = (
+            self.alerts_fetcher.query_pending_source_freshness_alerts(days_back)
+        )
+        last_alert_sent_times = (
+            self.alerts_fetcher.query_last_source_freshness_alert_times(days_back)
         )
-        last_alert_sent_times = self._query_last_source_freshness_alert_times(days_back)
         source_freshness_alerts = self._sort_alerts(
             pending_source_freshness_alerts, last_alert_sent_times, filter
         )
         return source_freshness_alerts
 
+    def skip_alerts(
+        self, alerts_to_skip: List[Union[AlertType, MalformedAlert]], table_name: str
+    ) -> None:
+        self.alerts_fetcher.skip_alerts(
+            alerts_to_skip=alerts_to_skip, table_name=table_name
+        )
+
+    def update_sent_alerts(self, alert_ids: List[str], table_name: str) -> None:
+        self.alerts_fetcher.update_sent_alerts(
+            alert_ids=alert_ids, table_name=table_name
+        )
+
     def _sort_alerts(
         self,
         pending_alerts: Union[
@@ -97,7 +118,7 @@ class AlertsAPI(APIClient):
             AlertsQueryResult[SourceFreshnessAlert],
         ],
         last_alert_sent_times: Dict[str, str],
-        filter: Optional[DataMonitoringAlertsFilter] = None,
+        filter: SelectorFilterSchema = SelectorFilterSchema(),
     ) -> Union[
         AlertsQueryResult[TestAlert],
         AlertsQueryResult[ModelAlert],
@@ -184,133 +205,3 @@ class AlertsAPI(APIClient):
         for alert_last_time in alert_last_times.values():
             latest_alert_ids.append(alert_last_time.get("alert_id"))
         return latest_alert_ids
-
-    def skip_alerts(
-        self, alerts_to_skip: List[Union[AlertType, MalformedAlert]], table_name: str
-    ):
-        alert_ids = [alert.id for alert in alerts_to_skip]
-        alert_ids_chunks = self._split_list_to_chunks(alert_ids)
-        for alert_ids_chunk in alert_ids_chunks:
-            self.dbt_runner.run_operation(
-                macro_name="update_skipped_alerts",
-                macro_args={
-                    "alert_ids": alert_ids_chunk,
-                    "table_name": table_name,
-                },
-                json_logs=False,
-            )
-
-    def _query_pending_test_alerts(
-        self, days_back: int, disable_samples: bool = False
-    ) -> AlertsQueryResult[TestAlert]:
-        logger.info("Querying test alerts.")
-        return self._query_alert_type(
-            {
-                "macro_name": "get_pending_test_alerts",
-                "macro_args": {
-                    "days_back": days_back,
-                    "disable_samples": disable_samples,
-                },
-            },
-            TestAlert.create_test_alert_from_dict,
-        )
-
-    def _query_pending_model_alerts(
-        self, days_back: int
-    ) -> AlertsQueryResult[ModelAlert]:
-        logger.info("Querying model alerts.")
-        return self._query_alert_type(
-            {
-                "macro_name": "get_pending_model_alerts",
-                "macro_args": {"days_back": days_back},
-            },
-            ModelAlert,
-        )
-
-    def _query_pending_source_freshness_alerts(
-        self, days_back: int
-    ) -> AlertsQueryResult[SourceFreshnessAlert]:
-        logger.info("Querying source freshness alerts.")
-        return self._query_alert_type(
-            {
-                "macro_name": "get_pending_source_freshness_alerts",
-                "macro_args": {"days_back": days_back},
-            },
-            SourceFreshnessAlert,
-        )
-
-    def _query_last_test_alert_times(self, days_back: int) -> Dict[str, str]:
-        logger.info("Querying test alerts last sent times.")
-        response = self.dbt_runner.run_operation(
-            macro_name="get_last_test_alert_sent_times",
-            macro_args={"days_back": days_back},
-        )
-        return json.loads(response[0])
-
-    def _query_last_model_alert_times(self, days_back: int) -> Dict[str, str]:
-        logger.info("Querying model alerts last sent times.")
-        response = self.dbt_runner.run_operation(
-            macro_name="get_last_model_alert_sent_times",
-            macro_args={"days_back": days_back},
-        )
-        return json.loads(response[0])
-
-    def _query_last_source_freshness_alert_times(
-        self, days_back: int
-    ) -> Dict[str, str]:
-        logger.info("Querying source freshness alerts last sent times.")
-        response = self.dbt_runner.run_operation(
-            macro_name="get_last_source_freshness_alert_sent_times",
-            macro_args={"days_back": days_back},
-        )
-        return json.loads(response[0])
-
-    def _query_alert_type(
-        self, run_operation_args: dict, alert_factory_func: Callable
-    ) -> AlertsQueryResult:
-        raw_alerts = self.dbt_runner.run_operation(**run_operation_args)
-        alerts = []
-        malformed_alerts = []
-        if raw_alerts:
-            alert_dicts = json.loads(raw_alerts[0])
-            for alert_dict in alert_dicts:
-                normalized_alert = self._normalize_alert(alert=alert_dict)
-                try:
-                    alerts.append(
-                        alert_factory_func(
-                            elementary_database_and_schema=self.elementary_database_and_schema,
-                            timezone=self.config.timezone,
-                            **normalized_alert,
-                        )
-                    )
-                except Exception:
-                    malformed_alerts.append(
-                        MalformedAlert(id=normalized_alert["id"], data=normalized_alert)
-                    )
-        if malformed_alerts:
-            logger.error("Failed to parse some alerts.")
-        return AlertsQueryResult(alerts, malformed_alerts)
-
-    @classmethod
-    def _normalize_alert(cls, alert: dict) -> dict:
-        return NormalizedAlert(alert).get_normalized_alert()
-
-    def update_sent_alerts(self, alert_ids: List[str], table_name: str) -> None:
-        alert_ids_chunks = self._split_list_to_chunks(alert_ids)
-        for alert_ids_chunk in alert_ids_chunks:
-            self.dbt_runner.run_operation(
-                macro_name="update_sent_alerts",
-                macro_args={
-                    "alert_ids": alert_ids_chunk,
-                    "sent_at": get_now_utc_str(),
-                    "table_name": table_name,
-                },
-                json_logs=False,
-            )
-
-    @staticmethod
-    def _split_list_to_chunks(items: list, chunk_size: int = 50) -> List[List]:
-        chunk_list = []
-        for i in range(0, len(items), chunk_size):
-            chunk_list.append(items[i : i + chunk_size])
-        return chunk_list
