@@ -1,25 +1,23 @@
-import json
 from collections import defaultdict
 from typing import List
 
 import networkx as nx
 
-from elementary.clients.api.api import APIClient
+from elementary.clients.api.api_client import APIClient
 from elementary.clients.dbt.dbt_runner import DbtRunner
-from elementary.monitor.api.lineage.schema import (
-    LineageNodeSchema,
-    LineageSchema,
-    NodeDependsOnNodesSchema,
-)
+from elementary.monitor.api.lineage.schema import LineageNodeSchema, LineageSchema
+from elementary.monitor.fetchers.lineage.lineage import LineageFetcher
+from elementary.monitor.fetchers.lineage.schema import NodeDependsOnNodesSchema
 
 
 class LineageAPI(APIClient):
     def __init__(self, dbt_runner: DbtRunner):
         super().__init__(dbt_runner)
+        self.lineage_fetcher = LineageFetcher(dbt_runner=self.dbt_runner)
 
     def get_lineage(self, exclude_elementary_models: bool = False) -> LineageSchema:
         lineage_graph = nx.DiGraph()
-        nodes_depends_on_nodes = self._get_nodes_depends_on_nodes(
+        nodes_depends_on_nodes = self.lineage_fetcher.get_nodes_depends_on_nodes(
             exclude_elementary_models
         )
         for node_depends_on_nodes in nodes_depends_on_nodes:
@@ -64,31 +62,6 @@ class LineageAPI(APIClient):
             )
         return dags
 
-    def _get_nodes_depends_on_nodes(
-        self, exclude_elementary_models: bool = False
-    ) -> List[NodeDependsOnNodesSchema]:
-        nodes_depends_on_nodes = []
-        nodes_depends_on_nodes_results = self.dbt_runner.run_operation(
-            macro_name="get_nodes_depends_on_nodes",
-            macro_args={"exclude_elementary": exclude_elementary_models},
-        )
-        if nodes_depends_on_nodes_results:
-            for node_depends_on_nodes_result in json.loads(
-                nodes_depends_on_nodes_results[0]
-            ):
-                nodes_depends_on_nodes.append(
-                    NodeDependsOnNodesSchema(
-                        unique_id=node_depends_on_nodes_result.get("unique_id"),
-                        depends_on_nodes=json.loads(
-                            node_depends_on_nodes_result.get("depends_on_nodes")
-                        )
-                        if node_depends_on_nodes_result.get("depends_on_nodes")
-                        else None,
-                        type=node_depends_on_nodes_result.get("type"),
-                    )
-                )
-        return nodes_depends_on_nodes
-
     @staticmethod
     def _convert_depends_on_node_to_lineage_node(
         nodes_depends_on_nodes: List[NodeDependsOnNodesSchema],
