@@ -1,28 +1,29 @@
-import json
 import re
 from collections import defaultdict
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Dict, List, Optional, Union
 
 from dateutil import tz
 
-from elementary.clients.api.api import APIClient
+from elementary.clients.api.api_client import APIClient
 from elementary.clients.dbt.dbt_runner import DbtRunner
 from elementary.monitor.api.invocations.invocations import InvocationsAPI
-from elementary.monitor.api.invocations.schema import DbtInvocationSchema
 from elementary.monitor.api.tests.schema import (
     DbtTestResultSchema,
     ElementaryTestResultSchema,
     InvocationSchema,
     InvocationsSchema,
-    ModelUniqueIdType,
     TestMetadataSchema,
-    TestResultDBRowSchema,
     TestResultSchema,
+    TestResultSummarySchema,
+    TestResultsWithTotalsSchema,
     TestRunSchema,
-    TestUniqueIdType,
+    TestRunsWithTotalsSchema,
     TotalsSchema,
 )
-from elementary.monitor.data_monitoring.schema import DataMonitoringReportFilter
+from elementary.monitor.data_monitoring.schema import SelectorFilterSchema
+from elementary.monitor.fetchers.invocations.schema import DbtInvocationSchema
+from elementary.monitor.fetchers.tests.schema import TestResultDBRowSchema
+from elementary.monitor.fetchers.tests.tests import TestsFetcher
 from elementary.utils.log import get_logger
 from elementary.utils.time import convert_utc_iso_format_to_datetime
 
@@ -30,138 +31,113 @@ logger = get_logger(__name__)
 
 
 class TestsAPI(APIClient):
-    def __init__(self, dbt_runner: DbtRunner):
+    def __init__(
+        self,
+        dbt_runner: DbtRunner,
+        days_back: Optional[int] = 7,
+        invocations_per_test: int = 720,
+        metrics_sample_limit: int = 5,
+        disable_passed_test_metrics: bool = False,
+    ):
         super().__init__(dbt_runner)
+        self.tests_fetcher = TestsFetcher(dbt_runner=self.dbt_runner)
         self.invocations_api = InvocationsAPI(dbt_runner)
+        self.test_results_db_rows = self._get_test_results_db_rows(
+            days_back=days_back,
+            invocations_per_test=invocations_per_test,
+            metrics_sample_limit=metrics_sample_limit,
+            disable_passed_test_metrics=disable_passed_test_metrics,
+        )
 
-    def get_all_test_results_db_rows(
+    def _get_test_results_db_rows(
         self,
         days_back: Optional[int] = 7,
         invocations_per_test: int = 720,
         metrics_sample_limit: int = 5,
         disable_passed_test_metrics: bool = False,
     ) -> List[TestResultDBRowSchema]:
-        run_operation_response = self.dbt_runner.run_operation(
-            macro_name="get_test_results",
-            macro_args=dict(
-                days_back=days_back,
-                invocations_per_test=invocations_per_test,
-                metrics_sample_limit=metrics_sample_limit,
-                disable_passed_test_metrics=disable_passed_test_metrics,
-            ),
+        return self.tests_fetcher.get_all_test_results_db_rows(
+            days_back=days_back,
+            invocations_per_test=invocations_per_test,
+            metrics_sample_limit=metrics_sample_limit,
+            disable_passed_test_metrics=disable_passed_test_metrics,
         )
-        test_results = (
-            json.loads(run_operation_response[0]) if run_operation_response else []
-        )
-        test_results = [
-            TestResultDBRowSchema(**test_result) for test_result in test_results
+
+    def get_test_results_summary(
+        self,
+        filter: SelectorFilterSchema = SelectorFilterSchema(),
+    ) -> List[TestResultSummarySchema]:
+        filtered_test_results_db_rows = self.test_results_db_rows
+        if filter.tag:
+            filtered_test_results_db_rows = [
+                test_result
+                for test_result in filtered_test_results_db_rows
+                if (filter.tag in test_result.tags)
+            ]
+        elif filter.owner:
+            filtered_test_results_db_rows = [
+                test_result
+                for test_result in filtered_test_results_db_rows
+                if (filter.owner in test_result.owners)
+            ]
+        elif filter.model:
+            filtered_test_results_db_rows = [
+                test_result
+                for test_result in filtered_test_results_db_rows
+                if (
+                    test_result.model_unique_id
+                    and test_result.model_unique_id.endswith(filter.model)
+                )
+            ]
+
+        filtered_test_results_db_rows = [
+            test_result
+            for test_result in filtered_test_results_db_rows
+            if test_result.invocations_rank_index == 1
         ]
-        return test_results
-
-    def _get_invocation_from_filter(
-        self, filter: DataMonitoringReportFilter
-    ) -> Optional[DbtInvocationSchema]:
-        # If none of the following filter options exists, the invocation is empty and there is no filter.
-        invocation = DbtInvocationSchema()
-        if filter.invocation_id:
-            invocation = self.invocations_api.get_invocation_by_id(
-                type="test", invocation_id=filter.invocation_id
+        return [
+            TestResultSummarySchema(
+                test_unique_id=test_result.test_unique_id,
+                elementary_unique_id=test_result.elementary_unique_id,
+                table_name=test_result.table_name,
+                column_name=test_result.column_name,
+                test_type=test_result.test_type,
+                test_sub_type=test_result.test_sub_type,
+                owners=test_result.model_owner,
+                tags=test_result.tags,
+                subscribers=self._get_test_subscribers(
+                    test_meta=test_result.meta, model_meta=test_result.model_meta
+                ),
+                description=test_result.meta.get("description"),
+                test_name=test_result.test_name,
+                status=test_result.status,
+                results_counter=test_result.failures,
             )
-        elif filter.invocation_time:
-            invocation = self.invocations_api.get_invocation_by_time(
-                type="test", invocation_max_time=filter.invocation_time
-            )
-        elif filter.last_invocation:
-            invocation = self.invocations_api.get_last_invocation(type="test")
-
-        return invocation
+            for test_result in filtered_test_results_db_rows
+        ]
 
     @staticmethod
-    def get_test_metadata_from_test_result_db_row(
-        test_result_db_row: TestResultDBRowSchema,
-    ) -> TestMetadataSchema:
-        test_display_name = (
-            test_result_db_row.test_name.replace("_", " ").title()
-            if test_result_db_row.test_name
-            else ""
-        )
-        detected_at_datetime = convert_utc_iso_format_to_datetime(
-            test_result_db_row.detected_at
-        )
-        detected_at_utc = detected_at_datetime
-        detected_at = detected_at_datetime.astimezone(tz.tzlocal())
-        table_full_name_parts = [
-            name
-            for name in [
-                test_result_db_row.database_name,
-                test_result_db_row.schema_name,
-                test_result_db_row.table_name,
-            ]
-            if name
-        ]
-        table_full_name = ".".join(table_full_name_parts).lower()
-        test_params = test_result_db_row.test_params
-        test_query = (
-            test_result_db_row.test_results_query.strip()
-            if test_result_db_row.test_results_query
-            else None
-        )
-
-        result = dict(
-            result_description=test_result_db_row.test_results_description,
-            result_query=test_query,
-        )
-
-        if test_result_db_row.test_type == "dbt_test":
-            configuration = dict(
-                test_name=test_result_db_row.test_name,
-                test_params=test_params,
-            )
+    def _get_test_subscribers(test_meta: dict, model_meta: dict) -> List[Optional[str]]:
+        subscribers = []
+        test_subscribers = test_meta.get("subscribers", [])
+        model_subscribers = model_meta.get("subscribers", [])
+        if isinstance(test_subscribers, list):
+            subscribers.extend(test_subscribers)
         else:
-            time_bucket_configuration = test_params.get("time_bucket", {})
-            time_bucket_count = time_bucket_configuration.get("count", 1)
-            time_bucket_period = time_bucket_configuration.get("period", "day")
-            configuration = dict(
-                test_name=test_result_db_row.test_name,
-                timestamp_column=test_params.get("timestamp_column"),
-                testing_timeframe=f"{time_bucket_count} {time_bucket_period}{'s' if time_bucket_count > 1 else ''}",
-                anomaly_threshold=test_params.get("sensitivity"),
-            )
+            subscribers.append(test_subscribers)
 
-        return TestMetadataSchema(
-            test_unique_id=test_result_db_row.test_unique_id,
-            elementary_unique_id=test_result_db_row.elementary_unique_id,
-            database_name=test_result_db_row.database_name,
-            schema_name=test_result_db_row.schema_name,
-            table_name=test_result_db_row.table_name,
-            column_name=test_result_db_row.column_name,
-            test_name=test_result_db_row.test_name,
-            test_display_name=test_display_name,
-            latest_run_time=detected_at.isoformat(),
-            latest_run_time_utc=detected_at_utc.isoformat(),
-            latest_run_status=test_result_db_row.status,
-            model_unique_id=test_result_db_row.model_unique_id,
-            table_unique_id=table_full_name,
-            test_type=test_result_db_row.test_type,
-            test_sub_type=test_result_db_row.test_sub_type,
-            test_query=test_query,
-            test_params=test_result_db_row.test_params,
-            test_created_at=test_result_db_row.test_created_at,
-            description=test_result_db_row.meta.get("description"),
-            result=result,
-            configuration=configuration,
-        )
+        if isinstance(model_subscribers, list):
+            subscribers.extend(model_subscribers)
+        else:
+            subscribers.append(model_subscribers)
+        return subscribers
 
     def get_test_results(
         self,
-        test_results_db_rows: List[TestResultDBRowSchema],
+        filter: SelectorFilterSchema = SelectorFilterSchema(),
         disable_samples: bool = False,
-        filter: Optional[DataMonitoringReportFilter] = None,
-    ) -> Tuple[
-        Dict[Optional[ModelUniqueIdType], List[TestResultSchema]],
-        Optional[DbtInvocationSchema],
-    ]:
-        filtered_test_results_db_rows = test_results_db_rows
+    ) -> TestResultsWithTotalsSchema:
+        filtered_test_results_db_rows = self.test_results_db_rows
         invocation = self._get_invocation_from_filter(filter)
         if invocation.invocation_id:
             filtered_test_results_db_rows = [
@@ -176,75 +152,33 @@ class TestsAPI(APIClient):
             if test_result.invocations_rank_index == 1
         ]
 
-        test_results = defaultdict(list)
+        tests_results = defaultdict(list)
         for test_result_db_row in filtered_test_results_db_rows:
             test_result = TestResultSchema(
-                metadata=self.get_test_metadata_from_test_result_db_row(
+                metadata=self._get_test_metadata_from_test_result_db_row(
                     test_result_db_row
                 ),
-                test_results=TestsAPI._get_test_result_from_test_result_db_row(
+                test_results=self._get_test_result_from_test_result_db_row(
                     test_result_db_row, disable_samples=disable_samples
                 ),
             )
-            test_results[test_result_db_row.model_unique_id].append(test_result)
+            tests_results[test_result_db_row.model_unique_id].append(test_result)
 
-        return test_results, invocation
+        test_metadatas = []
+        for test_results in tests_results.values():
+            test_metadatas.extend([result.metadata for result in test_results])
+        test_results_totals = self._get_total_tests_results(test_metadatas)
+        return TestResultsWithTotalsSchema(
+            results=tests_results,
+            totals=test_results_totals,
+            invocation=invocation,
+        )
 
-    @staticmethod
-    def _get_failed_rows_count(test_result_db_row: TestResultDBRowSchema) -> int:
-        failed_rows_count = -1
-        if (
-            test_result_db_row.status != "pass"
-            and test_result_db_row.test_results_description
-        ):
-            found_rows_number = re.search(
-                r"\d+", test_result_db_row.test_results_description
-            )
-            if found_rows_number:
-                found_rows_number = found_rows_number.group()
-                failed_rows_count = int(found_rows_number)
-        return failed_rows_count
-
-    @staticmethod
-    def _get_test_result_from_test_result_db_row(
-        test_result_db_row: TestResultDBRowSchema,
-        disable_samples: bool = False,
-    ) -> Union[DbtTestResultSchema, ElementaryTestResultSchema]:
-        test_results = None
-        sample_data = test_result_db_row.sample_data if not disable_samples else None
-        if test_result_db_row.test_type == "dbt_test":
-            test_results = DbtTestResultSchema(
-                display_name=test_result_db_row.test_name,
-                results_sample=sample_data,
-                error_message=test_result_db_row.test_results_description,
-                failed_rows_count=TestsAPI._get_failed_rows_count(test_result_db_row),
-            )
-        else:
-            test_sub_type_display_name = test_result_db_row.test_sub_type.replace(
-                "_", " "
-            ).title()
-            if test_result_db_row.test_type == "anomaly_detection":
-                if sample_data and test_result_db_row.test_sub_type != "dimension":
-                    sample_data.sort(key=lambda metric: metric.get("end_time"))
-                test_results = ElementaryTestResultSchema(
-                    display_name=test_sub_type_display_name,
-                    metrics=sample_data,
-                    result_description=test_result_db_row.test_results_description,
-                )
-            elif test_result_db_row.test_type == "schema_change":
-                test_results = ElementaryTestResultSchema(
-                    display_name=test_sub_type_display_name.lower(),
-                    result_description=test_result_db_row.test_results_description,
-                )
-        return test_results
-
-    def get_test_runs(
-        self, test_results_db_rows: List[TestResultDBRowSchema]
-    ) -> Dict[Optional[ModelUniqueIdType], List[TestRunSchema]]:
-        tests_invocations = self._get_invocations(test_results_db_rows)
+    def get_test_runs(self) -> TestRunsWithTotalsSchema:
+        tests_invocations = self._get_invocations(self.test_results_db_rows)
         latest_test_results = [
             test_result
-            for test_result in test_results_db_rows
+            for test_result in self.test_results_db_rows
             if test_result.invocations_rank_index == 1
         ]
 
@@ -254,18 +188,18 @@ class TestsAPI(APIClient):
                 test_result_db_row.elementary_unique_id
             )
             test_run = TestRunSchema(
-                metadata=self.get_test_metadata_from_test_result_db_row(
+                metadata=self._get_test_metadata_from_test_result_db_row(
                     test_result_db_row
                 ),
                 test_runs=test_invocations,
             )
             test_runs[test_result_db_row.model_unique_id].append(test_run)
-
-        return test_runs
+        test_runs_totals = self._get_total_tests_runs(tests_runs=test_runs)
+        return TestRunsWithTotalsSchema(runs=test_runs, totals=test_runs_totals)
 
     def _get_invocations(
         self, test_result_db_rows: List[TestResultDBRowSchema]
-    ) -> Dict[TestUniqueIdType, InvocationsSchema]:
+    ) -> Dict[str, InvocationsSchema]:
         grouped_invocations = defaultdict(list)
         grouped_invocation_ids = defaultdict(list)
         for test_result_db_row in test_result_db_rows:
@@ -343,7 +277,149 @@ class TestsAPI(APIClient):
         except Exception:
             return None
 
-    def get_total_tests_results(
+    def _get_invocation_from_filter(
+        self, filter: SelectorFilterSchema
+    ) -> Optional[DbtInvocationSchema]:
+        # If none of the following filter options exists, the invocation is empty and there is no filter.
+        invocation = DbtInvocationSchema()
+        if filter.invocation_id:
+            invocation = self.invocations_api.get_invocation_by_id(
+                type="test", invocation_id=filter.invocation_id
+            )
+        elif filter.invocation_time:
+            invocation = self.invocations_api.get_invocation_by_time(
+                type="test", invocation_max_time=filter.invocation_time
+            )
+        elif filter.last_invocation:
+            invocation = self.invocations_api.get_last_invocation(type="test")
+
+        return invocation
+
+    @staticmethod
+    def _get_test_metadata_from_test_result_db_row(
+        test_result_db_row: TestResultDBRowSchema,
+    ) -> TestMetadataSchema:
+        test_display_name = (
+            test_result_db_row.test_name.replace("_", " ").title()
+            if test_result_db_row.test_name
+            else ""
+        )
+        detected_at_datetime = convert_utc_iso_format_to_datetime(
+            test_result_db_row.detected_at
+        )
+        detected_at_utc = detected_at_datetime
+        detected_at = detected_at_datetime.astimezone(tz.tzlocal())
+        table_full_name_parts = [
+            name
+            for name in [
+                test_result_db_row.database_name,
+                test_result_db_row.schema_name,
+                test_result_db_row.table_name,
+            ]
+            if name
+        ]
+        table_full_name = ".".join(table_full_name_parts).lower()
+        test_params = test_result_db_row.test_params
+        test_query = (
+            test_result_db_row.test_results_query.strip()
+            if test_result_db_row.test_results_query
+            else None
+        )
+
+        result = dict(
+            result_description=test_result_db_row.test_results_description,
+            result_query=test_query,
+        )
+
+        if test_result_db_row.test_type == "dbt_test":
+            configuration = dict(
+                test_name=test_result_db_row.test_name,
+                test_params=test_params,
+            )
+        else:
+            time_bucket_configuration = test_params.get("time_bucket", {})
+            time_bucket_count = time_bucket_configuration.get("count", 1)
+            time_bucket_period = time_bucket_configuration.get("period", "day")
+            configuration = dict(
+                test_name=test_result_db_row.test_name,
+                timestamp_column=test_params.get("timestamp_column"),
+                testing_timeframe=f"{time_bucket_count} {time_bucket_period}{'s' if time_bucket_count > 1 else ''}",
+                anomaly_threshold=test_params.get("sensitivity"),
+            )
+
+        return TestMetadataSchema(
+            test_unique_id=test_result_db_row.test_unique_id,
+            elementary_unique_id=test_result_db_row.elementary_unique_id,
+            database_name=test_result_db_row.database_name,
+            schema_name=test_result_db_row.schema_name,
+            table_name=test_result_db_row.table_name,
+            column_name=test_result_db_row.column_name,
+            test_name=test_result_db_row.test_name,
+            test_display_name=test_display_name,
+            latest_run_time=detected_at.isoformat(),
+            latest_run_time_utc=detected_at_utc.isoformat(),
+            latest_run_status=test_result_db_row.status,
+            model_unique_id=test_result_db_row.model_unique_id,
+            table_unique_id=table_full_name,
+            test_type=test_result_db_row.test_type,
+            test_sub_type=test_result_db_row.test_sub_type,
+            test_query=test_query,
+            test_params=test_result_db_row.test_params,
+            test_created_at=test_result_db_row.test_created_at,
+            description=test_result_db_row.meta.get("description"),
+            result=result,
+            configuration=configuration,
+        )
+
+    @staticmethod
+    def _get_test_result_from_test_result_db_row(
+        test_result_db_row: TestResultDBRowSchema,
+        disable_samples: bool = False,
+    ) -> Union[DbtTestResultSchema, ElementaryTestResultSchema]:
+        test_results = None
+        sample_data = test_result_db_row.sample_data if not disable_samples else None
+        if test_result_db_row.test_type == "dbt_test":
+            test_results = DbtTestResultSchema(
+                display_name=test_result_db_row.test_name,
+                results_sample=sample_data,
+                error_message=test_result_db_row.test_results_description,
+                failed_rows_count=TestsAPI._get_failed_rows_count(test_result_db_row),
+            )
+        else:
+            test_sub_type_display_name = test_result_db_row.test_sub_type.replace(
+                "_", " "
+            ).title()
+            if test_result_db_row.test_type == "anomaly_detection":
+                if sample_data and test_result_db_row.test_sub_type != "dimension":
+                    sample_data.sort(key=lambda metric: metric.get("end_time"))
+                test_results = ElementaryTestResultSchema(
+                    display_name=test_sub_type_display_name,
+                    metrics=sample_data,
+                    result_description=test_result_db_row.test_results_description,
+                )
+            elif test_result_db_row.test_type == "schema_change":
+                test_results = ElementaryTestResultSchema(
+                    display_name=test_sub_type_display_name.lower(),
+                    result_description=test_result_db_row.test_results_description,
+                )
+        return test_results
+
+    @staticmethod
+    def _get_failed_rows_count(test_result_db_row: TestResultDBRowSchema) -> int:
+        failed_rows_count = -1
+        if (
+            test_result_db_row.status != "pass"
+            and test_result_db_row.test_results_description
+        ):
+            found_rows_number = re.search(
+                r"\d+", test_result_db_row.test_results_description
+            )
+            if found_rows_number:
+                found_rows_number = found_rows_number.group()
+                failed_rows_count = int(found_rows_number)
+        return failed_rows_count
+
+    def _get_total_tests_results(
         self,
         test_metadatas: List[TestMetadataSchema],
     ) -> Dict[Optional[str], TotalsSchema]:
@@ -356,8 +432,8 @@ class TestsAPI(APIClient):
             )
         return totals
 
-    def get_total_tests_runs(
-        self, tests_runs: Dict[Optional[ModelUniqueIdType], List[TestRunSchema]]
+    def _get_total_tests_runs(
+        self, tests_runs: Dict[Optional[str], List[TestRunSchema]]
     ) -> Dict[Optional[str], TotalsSchema]:
         totals = dict()
         for test_runs in tests_runs.values():
