@@ -135,7 +135,7 @@ def common_options(cmd: str):
             "--select",
             type=str,
             default=None,
-            help="Filter the report by tag:<TAG> / owner:<OWNER> / model:<MODEL> / last_invocation / invocation_id:<INVOCATION_ID> / invocation_time:<INVOCATION_TIME>."
+            help="Filter the report by last_invocation / invocation_id:<INVOCATION_ID> / invocation_time:<INVOCATION_TIME>."
             if cmd in (Command.REPORT, Command.SEND_REPORT)
             else "Filter the alerts by tag:<TAG> / owner:<OWNER> / model:<MODEL>.",
         )(func)
@@ -207,6 +207,12 @@ def get_cli_properties() -> dict:
     default=False,
     help="Whether to send a test message in case there are no alerts.",
 )
+@click.option(
+    "--group-by",
+    type=click.Choice(["alert", "table"]),
+    default="alert",
+    help="Whether to group alerts by 'alert' or by 'table'",
+)
 @click.pass_context
 def monitor(
     ctx,
@@ -229,6 +235,7 @@ def monitor(
     disable_samples,
     env,
     select,
+    group_by,
 ):
     """
     Get alerts on failures in dbt jobs.
@@ -255,6 +262,7 @@ def monitor(
         slack_channel_name=slack_channel_name,
         timezone=timezone,
         env=env,
+        slack_group_alerts_by=group_by,
     )
     anonymous_tracking = AnonymousTracking(config)
     anonymous_tracking.set_env("use_select", bool(select))
@@ -349,7 +357,6 @@ def report(
         Command.REPORT, get_cli_properties(), ctx.command.name
     )
     try:
-        config.validate_report()
         data_monitoring = DataMonitoringReport(
             config=config,
             tracking=anonymous_tracking,
@@ -448,6 +455,12 @@ def report(
     default=None,
     help="The report's file name, this is where it will be stored in the bucket (may contain folders).",
 )
+@click.option(
+    "--slack-report-url",
+    type=str,
+    default=None,
+    help="The URL the for the report at the Slack summary message (if not provided edr will assume the default bucket website url).",
+)
 @click.option(
     "--disable-passed-test-metrics",
     type=bool,
@@ -482,6 +495,7 @@ def send_report(
     project_profile_target,
     executions_limit,
     bucket_file_path,
+    slack_report_url,
     disable_passed_test_metrics,
     update_bucket_website,
     aws_profile_name,
@@ -523,6 +537,7 @@ def send_report(
         google_service_account_path=google_service_account_path,
         google_project_name=google_project_name,
         gcs_bucket_name=gcs_bucket_name,
+        slack_report_url=slack_report_url,
         env=env,
     )
     anonymous_tracking = AnonymousTracking(config)
