@@ -14,7 +14,7 @@
       *,
       false as alert_sent,  {# backwards compatibility #}
       'pending' as suppression_status,
-      {{ elementary.cast_as_string('NULL') }} as sent_at
+      {{ elementary.edr_cast_as_string('NULL') }} as sent_at
     from {{ alerts_source_freshness_relation }}
     {% if is_incremental() %}
         {{ get_new_alerts_where_clause(this) }}
