@@ -2,4 +2,4 @@ import os
 
 
 def is_debug() -> bool:
-    return "DEBUG" in os.environ
+    return "EDR_DEBUG" in os.environ
